@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0907';
+our $VERSION = '0.0908';
 
 use v5.36;
 
@@ -333,7 +333,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0907
+version 0.0908
 
 =head1 SYNOPSIS
 
@@ -627,6 +627,12 @@ should be applied.
 
 The F<eg/*.pl> program(s) in this distribution
 
+L<MIDI::RtController::Filter::Tonal> - Related module
+
+L<MIDI::RtController::Filter::Math> - Related module
+
+L<MIDI::RtController::Filter::Drums> - Related module
+
 L<IO::Async::Timer::Periodic>
 
 L<Iterator::Breathe>
